@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+#Copyright (C) 2010, 2011 Seán Hayes
+#
+#Licensed under a BSD 3-Clause License. See LICENSE file.
+
 from django.conf import settings
 import os
 import defaults
@@ -23,6 +28,3 @@ def patch_settings():
 	
 	if not hasattr(settings, 'HOST'):
 		settings.HOST = defaults.HOST
-	
-	if settings.ADMIN_MEDIA_PREFIX[:len(settings.MEDIA_URL)] == settings.MEDIA_URL:
-		settings.ADMIN_MEDIA_IN_MEDIA = True
